@@ -1,16 +1,13 @@
 import time
 
-import mock
+import httplib2
 import mox
-import requests
-import testtools
+import unittest2 as unittest
 
 from keystoneclient.v2_0 import client
 
 
-class TestCase(testtools.TestCase):
-    TEST_DOMAIN_ID = '1'
-    TEST_DOMAIN_NAME = 'aDomain'
+class TestCase(unittest.TestCase):
     TEST_TENANT_ID = '1'
     TEST_TENANT_NAME = 'aTenant'
     TEST_TOKEN = 'aToken'
@@ -19,9 +16,6 @@ class TestCase(testtools.TestCase):
     TEST_URL = '%s%s' % (TEST_ROOT_URL, 'v2.0')
     TEST_ROOT_ADMIN_URL = 'http://127.0.0.1:35357/'
     TEST_ADMIN_URL = '%s%s' % (TEST_ROOT_ADMIN_URL, 'v2.0')
-    TEST_REQUEST_BASE = {
-        'verify': True,
-    }
 
     TEST_SERVICE_CATALOG = [{
         "endpoints": [{
@@ -73,12 +67,9 @@ class TestCase(testtools.TestCase):
     def setUp(self):
         super(TestCase, self).setUp()
         self.mox = mox.Mox()
-        self.request_patcher = mock.patch.object(requests, 'request',
-                                                 self.mox.CreateMockAnything())
-        self.time_patcher = mock.patch.object(time, 'time',
-                                              lambda: 1234)
-        self.request_patcher.start()
-        self.time_patcher.start()
+        self._original_time = time.time
+        time.time = lambda: 1234
+        httplib2.Http.request = self.mox.CreateMockAnything()
         self.client = client.Client(username=self.TEST_USER,
                                     token=self.TEST_TOKEN,
                                     tenant_name=self.TEST_TENANT_NAME,
@@ -86,63 +77,28 @@ class TestCase(testtools.TestCase):
                                     endpoint=self.TEST_URL)
 
     def tearDown(self):
-        self.request_patcher.stop()
-        self.time_patcher.stop()
+        time.time = self._original_time
+        super(TestCase, self).tearDown()
         self.mox.UnsetStubs()
         self.mox.VerifyAll()
-        super(TestCase, self).tearDown()
 
 
-class UnauthenticatedTestCase(testtools.TestCase):
-    """Class used as base for unauthenticated calls."""
+class UnauthenticatedTestCase(unittest.TestCase):
+    """ Class used as base for unauthenticated calls """
     TEST_ROOT_URL = 'http://127.0.0.1:5000/'
     TEST_URL = '%s%s' % (TEST_ROOT_URL, 'v2.0')
     TEST_ROOT_ADMIN_URL = 'http://127.0.0.1:35357/'
     TEST_ADMIN_URL = '%s%s' % (TEST_ROOT_ADMIN_URL, 'v2.0')
-    TEST_REQUEST_BASE = {
-        'verify': True,
-    }
 
     def setUp(self):
         super(UnauthenticatedTestCase, self).setUp()
         self.mox = mox.Mox()
-        self.request_patcher = mock.patch.object(requests, 'request',
-                                                 self.mox.CreateMockAnything())
-        self.time_patcher = mock.patch.object(time, 'time',
-                                              lambda: 1234)
-        self.request_patcher.start()
-        self.time_patcher.start()
+        self._original_time = time.time
+        time.time = lambda: 1234
+        httplib2.Http.request = self.mox.CreateMockAnything()
 
     def tearDown(self):
-        self.request_patcher.stop()
-        self.time_patcher.stop()
+        time.time = self._original_time
+        super(UnauthenticatedTestCase, self).tearDown()
         self.mox.UnsetStubs()
         self.mox.VerifyAll()
-        super(UnauthenticatedTestCase, self).tearDown()
-
-
-class TestResponse(requests.Response):
-    """Class used to wrap requests.Response and provide some
-       convenience to initialize with a dict.
-    """
-
-    def __init__(self, data):
-        self._text = None
-        super(TestResponse, self).__init__()
-        if isinstance(data, dict):
-            self.status_code = data.get('status_code', None)
-            headers = data.get('headers')
-            if headers:
-                self.headers.update(headers)
-            # Fake the text attribute to streamline Response creation
-            # _content is defined by requests.Response
-            self._content = data.get('text', None)
-        else:
-            self.status_code = data
-
-    def __eq__(self, other):
-        return self.__dict__ == other.__dict__
-
-    @property
-    def text(self):
-        return self.content
